Description: Shrink (tls-)receiver-abort tests
 Reduce the message count so they reliably succeed on slow platforms like
 riscv64. Fast platforms work too.
Author: William Grant <wgrant@ubuntu.com>

Index: librelp-1.5.0/tests/receiver-abort.sh
===================================================================
--- librelp-1.5.0.orig/tests/receiver-abort.sh
+++ librelp-1.5.0/tests/receiver-abort.sh
@@ -4,9 +4,9 @@
 # of messages
 . ${srcdir:=$(pwd)}/test-framework.sh
 check_command_available timeout
-NUMMESSAGES=100000
+NUMMESSAGES=10000
 startup_receiver
-./send -t 127.0.0.1 -p $TESTPORT -n$NUMMESSAGES  --kill-on-msg 20000 --kill-pid $RECEIVE_PID $OPT_VERBOSE &
+./send -t 127.0.0.1 -p $TESTPORT -n$NUMMESSAGES  --kill-on-msg 2000 --kill-pid $RECEIVE_PID $OPT_VERBOSE &
 SENDER_PID=$!
 
 for i in {1..3};  do
Index: librelp-1.5.0/tests/tls-receiver-abort.sh
===================================================================
--- librelp-1.5.0.orig/tests/tls-receiver-abort.sh
+++ librelp-1.5.0/tests/tls-receiver-abort.sh
@@ -4,12 +4,12 @@
 # of messages
 . ${srcdir:=$(pwd)}/test-framework.sh
 check_command_available timeout
-export NUMMESSAGES=100000
+export NUMMESSAGES=10000
 
 actual_test() {
 	startup_receiver
 	./send -t 127.0.0.1 -p $TESTPORT -n$NUMMESSAGES \
-		--kill-on-msg 20000 --kill-pid $RECEIVE_PID $OPT_VERBOSE &
+		--kill-on-msg 2000 --kill-pid $RECEIVE_PID $OPT_VERBOSE &
 	SENDER_PID=$!
 
 	for i in {1..3};  do
